@@ -34,10 +34,15 @@ def format_mb(bytes):
 
 def main():
     if len(sys.argv) == 1:
-        print("Need video ID/URL")
-        return 1
+        urls = sys.stdin.readlines()
+    else:
+        urls = sys.argv[1:]
 
-    xml = objectify.fromstring(urllib.request.urlopen(XML_API % get_id(sys.argv[-1])).read())
+    for url in urls:
+        video_dl(url)
+
+def video_dl(url):
+    xml = objectify.fromstring(urllib.request.urlopen(XML_API % get_id(url)).read())
 
     status = xml.status
     if status.statuscode.text != "ok":
